@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -50,7 +47,7 @@ class Bootstrap4BadgePlugin(CMSPluginBase):
         ])
         instance.attributes['class'] = classes
 
-        return super(Bootstrap4BadgePlugin, self).render(
+        return super().render(
             context, instance, placeholder
         )
 
