@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -47,7 +44,7 @@ class Bootstrap4SpacingPlugin(CMSPluginBase):
             instance.attributes.get('class'),
         ])
 
-        return super(Bootstrap4SpacingPlugin, self).render(
+        return super().render(
             context, instance, placeholder
         )
 
